==> igniteui-react-18.2.2-beta.0.tgz: package/esm2015/lib/PaneHeaderConnectionEventArgsDetail.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
import { ContentPane } from "./ContentPane";
import { PaneHeaderElement } from "./PaneHeaderElement";
/**
 * @hidden
 */
export let PaneHeaderConnectionEventArgsDetail = /*@__PURE__*/ (() => {
    class PaneHeaderConnectionEventArgsDetail extends Base {
        constructor() {
            super(...arguments);
            this.c = new WCNativeHelper();
            this.e = null;
        }
        get d() {
            return this.c;
        }
        get nativeElement() {
            return this.e;
        }
        set nativeElement(a) {
            this.e = a;
            this.c.n = this.e;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get a() {
            let ret_ = this.d.l("pane", (a) => new ContentPane());
            return ret_;
        }
        set a(a) {
            let value_ = a;
            this.d.u("pane", value_);
        }
        get b() {
            let ret_ = this.d.l("element", (a) => new PaneHeaderElement());
            return ret_;
        }
        set b(a) {
            let value_ = a;
            this.d.u("element", value_);
        }
    }
    PaneHeaderConnectionEventArgsDetail.$t = /*@__PURE__*/ markType(PaneHeaderConnectionEventArgsDetail, 'PaneHeaderConnectionEventArgsDetail');
    return PaneHeaderConnectionEventArgsDetail;
})();

==> igniteui-react-18.3.0-beta.0.tgz: package/esm2015/lib/PaneHeaderConnectionEventArgsDetail.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
import { ContentPane } from "./ContentPane";
import { PaneHeaderElement } from "./PaneHeaderElement";
/**
 * @hidden
 */
export let PaneHeaderConnectionEventArgsDetail = /*@__PURE__*/ (() => {
    class PaneHeaderConnectionEventArgsDetail extends Base {
        constructor() {
            super(...arguments);
            this.c = new WCNativeHelper();
            this.e = null;
        }
        get d() {
            return this.c;
        }
        get nativeElement() {
            return this.e;
        }
        set nativeElement(a) {
            this.e = a;
            this.c.o = this.e;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get a() {
            let ret_ = this.d.m("pane", (a) => new ContentPane());
            return ret_;
        }
        set a(a) {
            let value_ = a;
            this.d.v("pane", value_);
        }
        get b() {
            let ret_ = this.d.m("element", (a) => new PaneHeaderElement());
            return ret_;
        }
        set b(a) {
            let value_ = a;
            this.d.v("element", value_);
        }
    }
    PaneHeaderConnectionEventArgsDetail.$t = /*@__PURE__*/ markType(PaneHeaderConnectionEventArgsDetail, 'PaneHeaderConnectionEventArgsDetail');
    return PaneHeaderConnectionEventArgsDetail;
})();
